@@ -213,7 +213,7 @@ use constant SWQL_getVolumeMap=>q{SELECT
     VolumeID,
     NodeID
 
-  FROM Orion.Volumes where NodeID=%s order by VolumeIndex desc};
+  FROM Orion.Volumes where NodeID=%s};
 
 =item * my $sql=$self->SWQL_GetNodePollers;
 
@@ -231,6 +231,8 @@ use constant SWQL_GetNodePollers=>q{SELECT Description, DisplayName, Enabled, In
 
 =item * my $sql=$self->SWQL_GetNodeInterfacePollers;
 
+=item * my $sql=$self->SWQL_get_poller_map;
+
 =cut 
 
 use constant SWQL_getPollerInterfaceMap=>q{select
@@ -259,6 +261,9 @@ use constant SWQL_GetNodeInterfacePollers=>q{select
     i.NodeID=%s
     order by i.InterfaceID};
 
+
+use constant SWQL_get_poller_map=>q{SELECT Description, DisplayName, Enabled, InstanceType, NetObject, NetObjectID, NetObjectType, PollerID, PollerType, Uri FROM Orion.Pollers where NetObjectID=%s and NetObjectType='%s'};
+
 =back
 
 =head1 Author
