@@ -39,7 +39,7 @@ use Net::SolarWinds::Log;
 use JSON qw();
 use URI::Encode qw(uri_encode);
 
-our $VERSION=0.10;
+our $VERSION=0.11;
 
 use base qw(Net::SolarWinds::ConstructorHash Net::SolarWinds::LogMethods Net::SolarWinds::Helper);
 use constant RESULT_CLASS=>'Net::SolarWinds::Result';
@@ -1022,6 +1022,29 @@ sub GetNodePollers {
   return $self->RESULT_CLASS->new_true($pollers);
 }
 
+=item my $result=$self->UpdateUri($uri,%args);
+
+Read/Write Interface used update or get the contents of $uri.  Returns a Net::SolarWinds::Result object.  Write Mode is used when %args contains values Read Mode is used when %args is empty
+
+=cut
+
+sub UpdateUri {
+  my ($self,$uri,%args)=@_;
+
+  $self->log_info("starting Uri: $uri");
+  my $request; 
+  if(scalar(keys(%args))==0) {
+    $self->log_info("called in Read mode");
+    $request=$self->build_request('GET',$uri);
+  } else {
+    $self->log_info("called in Write mode");
+    $request=$self->build_request('POST',$uri,{%args});
+  }
+  my $result=$self->run_request($request);
+  $self->log_info("stopping Uri $uri");
+  return $result;
+}
+
 =back
 
 =head1 SEE ALSO
