@@ -386,8 +386,9 @@ Returns a Net::SolarWinds::Result object.
 sub get_poller_map {
   my ($self,$node_id,$type)=@_;
 
+  $type='N' unless defined($type);
   $self->log_info("starting node_id: $node_id type: $type");
-  my $query=q{SELECT Description, DisplayName, Enabled, InstanceType, NetObject, NetObjectID, NetObjectType, PollerID, PollerType, Uri FROM Orion.Pollers where NetObjectID=}.$node_id;
+  my $query=$self->query_lookup($node_id,$type);
   my $result=$self->Query($query);
   unless($result) {
     $self->log_error("query failed error was: $result");
@@ -557,6 +558,9 @@ sub add_volumes {
 
   my $added={};
   PROV_LOOP: foreach my $vol (@vols) {
+    # force the object to a hash ref..
+    $vol={path=>$vol} 
+      unless ref($vol) and ref($vol) eq 'HASH';
     my $path=$vol->{path};
     my $obj;
     if(exists $vol_map->{$path}) {
@@ -566,19 +570,15 @@ sub add_volumes {
       ++$MaxVolumeIndex;
       $self->log_warn("volume does not exist we will create: $path");
       #%{ $map->{$vol->{type}}},
-      my $type=$vol->{type};
-      my %type_options;
-      # perhaps the snmp lookup can fail?
-      %type_options=%{ $map->{$type} } if exists $map->{$type};
 
       my %args=(
         Caption=>$path,
         VolumeDescription=>$path,
         NodeID=>$node_id,
 	VolumeIndex=>$MaxVolumeIndex,
-	%type_options
       );
 
+      $self->log_always("Adding volume with options: ",Dumper(\%args));
       $result=$self->add_volume(%args);
       unless($result) {
         $self->log_warn("failed to add volume $path error was: $result");
@@ -597,12 +597,13 @@ sub add_volumes {
       my $pollers=$vol->{pollers};
       my $volume_id=$obj->{VolumeID};
         my $result=$self->add_pollers($volume_id,'V',@{$pollers});
-	unless($result) {
+	if($result) {
+	  $added->{$path}->{pollers}=$result->get_data;
+        } else {
 	  $self->log_error("failed to add pollers to volume: $volume_id error was: $result");
 	  $self->log_info("stopping");
-	  return $result;
+	  $added->{$path}->{pollers}={ERROR=>"$result"};
 	}
-	$added->{pollers}=$result->get_data;
     }
   }
 
